@@ -54,7 +54,7 @@ from hypothesis.reporting import report, verbose_report, current_verbosity
 from hypothesis.statistics import note_engine_for_statistics
 from hypothesis.internal.compat import ceil, hbytes, qualname, \
     str_to_bytes, benchmark_time, get_type_hints, getfullargspec, \
-    encoded_filepath, bad_django_TestCase
+    int_from_bytes, encoded_filepath, bad_django_TestCase
 from hypothesis.internal.coverage import IN_COVERAGE_TESTS
 from hypothesis.utils.conventions import infer, not_set
 from hypothesis.internal.escalation import is_hypothesis_file, \
@@ -300,7 +300,7 @@ def get_random_for_wrapped_test(test, wrapped_test):
         return Random(
             wrapped_test._hypothesis_internal_use_seed)
     elif settings.derandomize:
-        return Random(function_digest(test))
+        return Random(int_from_bytes(function_digest(test)))
     elif global_force_seed is not None:
         return Random(global_force_seed)
     else:
@@ -678,7 +678,7 @@ class StateForActualGivenExecution(object):
                             arc(filename, source, target)
                             for source, target in covdata.arcs(filename)
                         )
-            if result is not None and self.settings.perform_health_check:
+            if result is not None:
                 fail_health_check(self.settings, (
                     'Tests run under @given should return None, but '
                     '%s returned %r instead.'
@@ -776,31 +776,23 @@ class StateForActualGivenExecution(object):
                 ) % (
                     self.settings.timeout, runner.valid_examples),
                     self.settings)
-            if runner.valid_examples < min(
-                self.settings.min_satisfying_examples,
-                self.settings.max_examples,
-            ) and not (
+            if runner.valid_examples <= 1 and not (
                 runner.exit_reason == ExitReason.finished and
                 self.at_least_one_success
             ):
                 if timed_out:
                     raise Timeout((
                         'Ran out of time before finding a satisfying '
-                        'example for '
-                        '%s. Only found %d examples in ' +
-                        '%.2fs.'
+                        'example for %s. Only found %d examples in %.2fs.'
                     ) % (
                         get_pretty_function_description(self.test),
                         runner.valid_examples, run_time
                     ))
                 else:
-                    raise Unsatisfiable((
-                        'Unable to satisfy assumptions of hypothesis '
-                        '%s. Only %d examples considered '
-                        'satisfied assumptions'
-                    ) % (
-                        get_pretty_function_description(self.test),
-                        runner.valid_examples,))
+                    raise Unsatisfiable(
+                        'Unable to satisfy assumptions of hypothesis %s.' %
+                        (get_pretty_function_description(self.test),)
+                    )
 
         if not self.falsifying_examples:
             return
@@ -1093,10 +1085,9 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
     matches the predicate function ``condition``."""
     settings = settings or Settings(
         max_examples=2000,
-        min_satisfying_examples=0,
         max_shrinks=2000,
     )
-    settings = Settings(settings, perform_health_check=False)
+    settings = Settings(settings, suppress_health_check=HealthCheck.all())
 
     if database_key is None and settings.database is not None:
         database_key = function_digest(condition)
@@ -1128,7 +1119,7 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
         if success:
             successful_examples[0] += 1
 
-        if settings.verbosity == Verbosity.verbose:
+        if settings.verbosity >= Verbosity.verbose:
             if not successful_examples[0]:
                 report(
                     u'Tried non-satisfying example %s' % (nicerepr(result),))
@@ -1159,12 +1150,11 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
             list(runner.interesting_examples.values())[0].buffer)
         with BuildContext(data):
             return data.draw(search)
-    if (
-        runner.valid_examples <= settings.min_satisfying_examples and
+    if runner.valid_examples == 0 and (
         runner.exit_reason != ExitReason.finished
     ):
         if settings.timeout > 0 and run_time > settings.timeout:
-            raise Timeout((
+            raise Timeout((  # pragma: no cover
                 'Ran out of time before finding enough valid examples for '
                 '%s. Only %d valid examples found in %.2f seconds.'
             ) % (
@@ -1172,11 +1162,9 @@ def find(specifier, condition, settings=None, random=None, database_key=None):
                 runner.valid_examples, run_time))
 
         else:
-            raise Unsatisfiable((
-                'Unable to satisfy assumptions of '
-                '%s. Only %d examples considered satisfied assumptions'
-            ) % (
-                get_pretty_function_description(condition),
-                runner.valid_examples,))
+            raise Unsatisfiable(
+                'Unable to satisfy assumptions of %s.' %
+                (get_pretty_function_description(condition),)
+            )
 
     raise NoSuchExample(get_pretty_function_description(condition))
